State

Enum State 

#[non_exhaustive]
pub enum State {
Show 13 variants Unconfigured, ConfigInProgress, ConfigReceived, ConfigFailed, PixelsInProgress, PixelsReceived, PixelsFailed, PageLoaded, PageLoadInProgress, PageShown, PageShowInProgress, ShowingPages, ReadyToReset,
}
Possible states that a sign can be in during operation.

These are reported by the sign in a ReportState message in response to Hello or QueryState.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unconfigured

The initial state upon power on or after a reset. No configuration or pixel data stored.



ConfigInProgress

The sign is waiting for the ODK to send the 16-byte configuration data.



ConfigReceived

The configuration data was successfully received.



ConfigFailed

Error encountered while reading the configuration data.



PixelsInProgress

The sign is waiting for the ODK to send the pixel data.



PixelsReceived

Pixel data was successfully received.



PixelsFailed

Error encountered while reading the pixel data.



PageLoaded

Page was loaded into memory and is ready to be shown.



PageLoadInProgress

Page is in the process of being loaded into memory.



PageShown

Loaded page was successfully shown.



PageShowInProgress

Page is in the process of being shown.



ShowingPages

The sign is automatically flipping between pages. Mutually exclusive with the Page* states above.



ReadyToReset

Sign is ready to reset back to the Unconfigured state.